@@ -15,7 +15,9 @@
 # limitations under the License.
 
 
-def parse(xml_or_file, parser=None, version = None):
+__version__ = '1.3.5'
+
+def parse(xml_or_file, version = None):
     """
     Parse xml (string) or file object. This is just an wrapper for
     GPXParser.parse() function.
@@ -31,6 +33,6 @@ def parse(xml_or_file, parser=None, version = None):
 
     from . import parser as mod_parser
 
-    parser = mod_parser.GPXParser(xml_or_file, parser=parser)
+    parser = mod_parser.GPXParser(xml_or_file)
 
     return parser.parse(version)
